@@ -1,30 +1,39 @@
 /*
-    QRoundProgressBar - a circular progress bar Qt widget.
+ * QRoundProgressBar - a circular progress bar Qt widget.
+ *
+ * Sintegrial Technologies (c) 2015-now
+ *
+ * The software is freeware and is distributed "as is" with the complete source codes.
+ * Anybody is free to use it in any software projects, either commercial or non-commercial.
+ * Please do not remove this copyright message and remain the name of the author unchanged.
+ *
+ * It is very appreciated if you produce some feedback to us case you are going to use
+ * the software.
+ *
+ * Please send your questions, suggestions, and information about found issues to the
+ *
+ * sintegrial@gmail.com
+ *
+ */
 
-    Sintegrial Technologies (c) 2015-now
-
-    The software is freeware and is distributed "as is" with the complete source codes.
-    Anybody is free to use it in any software projects, either commercial or non-commercial.
-    Please do not remove this copyright message and remain the name of the author unchanged.
-
-    It is very appreciated if you produce some feedback to us case you are going to use
-    the software.
-
-    Please send your questions, suggestions, and information about found issues to the
-
-    sintegrial@gmail.com
-
-*/
 
 #include "QRoundProgressBar.h"
 
-#include <QPainter>
-#include <QPainterPath>
+#include <QtGui/QPainter>
 
-QRoundProgressBar::QRoundProgressBar(QWidget *parent)
-    : QWidget(parent), m_min(0), m_max(100), m_value(25), m_nullPosition(PositionTop), m_barStyle(StyleDonut),
-      m_outlinePenWidth(1), m_dataPenWidth(1), m_rebuildBrush(false), m_format("%p%"), m_decimals(1),
-      m_updateFlags(UF_PERCENT)
+
+QRoundProgressBar::QRoundProgressBar(QWidget *parent) :
+    QWidget(parent),
+    m_min(0), m_max(100),
+    m_value(25),
+    m_nullPosition(PositionTop),
+    m_barStyle(StyleDonut),
+    m_outlinePenWidth(1),
+    m_dataPenWidth(1),
+    m_rebuildBrush(false),
+    m_format("%p%"),
+    m_decimals(1),
+    m_updateFlags(UF_PERCENT)
 {
 }
 
@@ -143,7 +152,8 @@ void QRoundProgressBar::setFormat(const QString &format)
 
 void QRoundProgressBar::resetFormat()
 {
-    m_format.clear();
+    m_format = QString::null;
+
     valueFormatChanged();
 }
 
@@ -157,11 +167,10 @@ void QRoundProgressBar::setDecimals(int count)
     }
 }
 
-void QRoundProgressBar::paintEvent(QPaintEvent * /*event*/)
+void QRoundProgressBar::paintEvent(QPaintEvent* /*event*/)
 {
-#if 0
     double outerRadius = qMin(width(), height());
-    QRectF baseRect(1, 1, outerRadius - 2, outerRadius - 2);
+    QRectF baseRect(1, 1, outerRadius-2, outerRadius-2);
 
     QImage buffer(outerRadius, outerRadius, QImage::Format_ARGB32_Premultiplied);
 
@@ -195,60 +204,39 @@ void QRoundProgressBar::paintEvent(QPaintEvent * /*event*/)
 
     QPainter painter(this);
     painter.fillRect(baseRect, palette().background());
-    painter.drawImage(0, 0, buffer);
-#endif
-    double outerRadius = qMin(width(), height());
-    QRectF baseRect(1, 1, outerRadius - 2, outerRadius - 2);
-    QPainter p(this);
-    //painter.fillRect(baseRect, palette().window());
-    p.setRenderHint(QPainter::Antialiasing);
-    p.fillRect(baseRect, Qt::NoBrush);
-    drawBase(p, baseRect);
-    // data circle
-    double arcStep = 360.0 / (m_max - m_min) * m_value;
-    drawValue(p, baseRect, m_value, arcStep);
-
-    // center circle
-    double innerRadius(0);
-    QRectF innerRect;
-    calculateInnerRect(baseRect, outerRadius, innerRect, innerRadius);
-    drawInnerBackground(p, innerRect);
-
-    // text
-    drawText(p, innerRect, innerRadius, m_value);
+    painter.drawImage(0,0, buffer);
 }
 
 void QRoundProgressBar::drawBackground(QPainter &p, const QRectF &baseRect)
 {
-    p.fillRect(baseRect, palette().window());
+    p.fillRect(baseRect, palette().background());
 }
 
 void QRoundProgressBar::drawBase(QPainter &p, const QRectF &baseRect)
 {
     switch (m_barStyle)
     {
-        case StyleDonut:
-            p.setPen(QPen(palette().shadow().color(), m_outlinePenWidth));
-            p.setBrush(palette().base());
-            p.drawEllipse(baseRect);
-            break;
+    case StyleDonut:
+        p.setPen(QPen(palette().shadow().color(), m_outlinePenWidth));
+        p.setBrush(palette().base());
+        p.drawEllipse(baseRect);
+        break;
 
-        case StylePie:
-            p.setPen(QPen(palette().base().color(), m_outlinePenWidth));
-            p.setBrush(palette().base());
-            p.drawEllipse(baseRect);
-            break;
+    case StylePie:
+        p.setPen(QPen(palette().base().color(), m_outlinePenWidth));
+        p.setBrush(palette().base());
+        p.drawEllipse(baseRect);
+        break;
 
-        case StyleLine:
-            p.setPen(QPen(palette().base().color(), m_outlinePenWidth));
-            p.setBrush(Qt::NoBrush);
-            p.drawEllipse(baseRect.adjusted(m_outlinePenWidth / 2, m_outlinePenWidth / 2, -m_outlinePenWidth / 2,
-                                            -m_outlinePenWidth / 2));
-            break;
+    case StyleLine:
+        p.setPen(QPen(palette().base().color(), m_outlinePenWidth));
+        p.setBrush(Qt::NoBrush);
+        p.drawEllipse(baseRect.adjusted(m_outlinePenWidth/2, m_outlinePenWidth/2, -m_outlinePenWidth/2, -m_outlinePenWidth/2));
+        break;
 
-        default:
-            ;
+    default:;
     }
+
 }
 
 void QRoundProgressBar::drawValue(QPainter &p, const QRectF &baseRect, double value, double arcLength)
@@ -262,9 +250,9 @@ void QRoundProgressBar::drawValue(QPainter &p, const QRectF &baseRect, double va
     {
         p.setPen(QPen(palette().highlight().color(), m_dataPenWidth));
         p.setBrush(Qt::NoBrush);
-        p.drawArc(baseRect.adjusted(m_outlinePenWidth / 2, m_outlinePenWidth / 2, -m_outlinePenWidth / 2,
-                                    -m_outlinePenWidth / 2),
-                  m_nullPosition * 16, -arcLength * 16);
+        p.drawArc(baseRect.adjusted(m_outlinePenWidth/2, m_outlinePenWidth/2, -m_outlinePenWidth/2, -m_outlinePenWidth/2),
+                  m_nullPosition * 16,
+                  -arcLength * 16);
         return;
     }
 
@@ -282,21 +270,20 @@ void QRoundProgressBar::drawValue(QPainter &p, const QRectF &baseRect, double va
     p.drawPath(dataPath);
 }
 
-void QRoundProgressBar::calculateInnerRect(const QRectF & /*baseRect*/, double outerRadius, QRectF &innerRect,
-        double &innerRadius)
+void QRoundProgressBar::calculateInnerRect(const QRectF &/*baseRect*/, double outerRadius, QRectF &innerRect, double &innerRadius)
 {
     // for Line style
     if (m_barStyle == StyleLine)
     {
         innerRadius = outerRadius - m_outlinePenWidth;
     }
-    else // for Pie and Donut styles
+    else    // for Pie and Donut styles
     {
         innerRadius = outerRadius * 0.75;
     }
 
     double delta = (outerRadius - innerRadius) / 2;
-    innerRect    = QRectF(delta, delta, innerRadius, innerRadius);
+    innerRect = QRectF(delta, delta, innerRadius, innerRadius);
 }
 
 void QRoundProgressBar::drawInnerBackground(QPainter &p, const QRectF &innerRect)
@@ -365,7 +352,7 @@ void QRoundProgressBar::rebuildDataBrushIfNeeded()
         m_rebuildBrush = false;
 
         QConicalGradient dataBrush;
-        dataBrush.setCenter(0.5, 0.5);
+        dataBrush.setCenter(0.5,0.5);
         dataBrush.setCoordinateMode(QGradient::StretchToDeviceMode);
 
         // invert colors
@@ -382,3 +369,6 @@ void QRoundProgressBar::rebuildDataBrushIfNeeded()
         setPalette(p);
     }
 }
+
+
+
