@@ -33,6 +33,9 @@ public:
 private slots:
     void saveFITSDirectory();
     void saveDriversDirectory();
+    void slotShowLogFiles();
+    void toggleINDIInternal();
+    void toggleDriversInternal();
 
 private:
     KConfigDialog *m_ConfigDialog;
