@@ -18,18 +18,32 @@
 
 #include <QDebug>
 #include <QPixmap>
+
+#include <QApplication>
+#include <QScreen>
+
+#ifdef KSTARS_LITE
+#include "kstarslite.h"
+#include <KLocalizedString>
+#else
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 
 #include <KAboutData>
 #include <KCrash>
 #include <KLocalizedString>
-#include "kspaths.h"
 
 #include "kstars.h"
-#include "kstarsdata.h"
-#include "kstarsdatetime.h"
 #include "skymap.h"
+#endif
+//DELETE!
+#include "projections/projector.h"
+
+#include "kspaths.h"
+
+#include "kstarsdata.h"
+#include "ksutils.h"
+#include "kstarsdatetime.h"
 #include "simclock.h"
 #include "ksnumbers.h"
 #include "version.h"
@@ -37,29 +51,46 @@
 
 
 static const char description[] =
-    I18N_NOOP("Desktop Planetarium");
+        I18N_NOOP("Desktop Planetarium");
 static const char notice[] =
-    I18N_NOOP("Some images in KStars are for non-commercial use only.  See README.images.");
+        I18N_NOOP("Some images in KStars are for non-commercial use only.  See README.images.");
 
 
 int main(int argc, char *argv[])
 {
+#ifdef KSTARS_LITE
+    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
     QApplication app(argc, argv);
-    app.setApplicationVersion(KSTARS_VERSION);
 
+#ifdef Q_OS_OSX
+    //Note, this function will return true on OS X if the data directories are good to go.  If not, quit with error code 1!
+    if(!KSUtils::copyDataFolderFromAppBundleIfNeeded()){
+        KMessageBox::sorry(0, i18n("Sorry, without a KStars Data Directory, KStars cannot operate. Exiting program now."));
+        return 1;
+    }
+#endif
+    app.setApplicationVersion(KSTARS_VERSION);
     /**
     * enable high dpi support
     */
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
+    KLocalizedString::setApplicationDomain("kstars");    
+#ifndef KSTARS_LITE
     KCrash::initialize();
 
-    KLocalizedString::setApplicationDomain("kstars");
-
     KAboutData aboutData( "kstars", i18n("KStars"), KSTARS_VERSION, i18n(description), KAboutLicense::GPL,
-                          i18n("(c) 2001-2015, The KStars Team"), i18n(notice), "http://edu.kde.org/kstars");
+                          "2001-" + QString::number(QDate::currentDate().year()) + i18n("(c), The KStars Team"), i18n(notice), "http://edu.kde.org/kstars");
     aboutData.addAuthor(i18n("Jason Harris"), i18n("Original Author"), "jharris@30doradus.org", "http://www.30doradus.org");
     aboutData.addAuthor(i18n("Jasem Mutlaq"), i18n("Current Maintainer"), "mutlaqja@ikarustech.com", "http://www.indilib.org");
+
+    // Active developers
+    aboutData.addAuthor(i18n("Akarsh Simha"), QString(), "akarsh@kde.org", "http://www.ph.utexas.edu/~asimha");
+    aboutData.addAuthor(i18n("Artem Fedoskin"), i18n("KStars Lite"), "afedoskin3@gmail.com");
+    aboutData.addAuthor(i18n("Robert Lancaster"), i18n("FITSViewer Improvements. KStars OSX Port"), "rlancaste@gmail.com");
+
+    // Inactive developers
     aboutData.addAuthor(i18n("James Bowlin"), QString(), "bowlin@mindspring.com");
     aboutData.addAuthor(i18n("Pablo de Vicente"), QString(), "pvicentea@wanadoo.es");
     aboutData.addAuthor(i18n("Thomas Kabelmann"), QString(), "tk78@gmx.de");
@@ -67,8 +98,7 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18n("Carsten Niehaus"), QString(), "cniehaus@gmx.de");
     aboutData.addAuthor(i18n("Mark Hollomon"), QString(), "mhh@mindspring.com");
     aboutData.addAuthor(i18n("Alexey Khudyakov"), QString(), "alexey.skladnoy@gmail.com");
-    aboutData.addAuthor(i18n("M&eacute;d&eacute;ric Boquien"), QString(), "mboquien@free.fr");
-    aboutData.addAuthor(i18n("Akarsh Simha"), QString(), "akarsh@kde.org", "http://www.ph.utexas.edu/~asimha");
+    aboutData.addAuthor(i18n("M&eacute;d&eacute;ric Boquien"), QString(), "mboquien@free.fr");    
     aboutData.addAuthor(i18n("J&eacute;r&ocirc;me Sonrier"), QString(), "jsid@emor3j.fr.eu.org");
     aboutData.addAuthor(i18n("Prakash Mohan"), QString(), "prakash.mohan@kdemail.net");
     aboutData.addAuthor(i18n("Victor Cărbune"), QString(), "victor.carbune@kdemail.net");
@@ -77,13 +107,15 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18n("Rafał Kułaga"), QString(), "rl.kulaga@gmail.com");
     aboutData.addAuthor(i18n("Rishab Arora"), QString(), "ra.rishab@gmail.com");
 
+    // Contributors
     aboutData.addCredit(i18n("Valery Kharitonov"), i18n("Converted labels containing technical terms to links to documentation") );
     aboutData.addCredit(i18n("Ana-Maria Constantin"), i18n("Technical documentation on Astronomy and KStars") );
     aboutData.addCredit(i18n("Andrew Stepanenko"), i18n("Guiding code based on lin_guider") );
     aboutData.addCredit(i18n("Nuno Pinheiro"), i18n("Artwork") );
-    aboutData.addCredit(i18n("Utkarsh Simha"), i18n("Improvements to observation plan execution, star hopper etc.") );    
+    aboutData.addCredit(i18n("Utkarsh Simha"), i18n("Improvements to observation plan execution, star hopper etc.") );
     aboutData.addCredit(i18n("Daniel Holler"), i18n("Extensive testing and suggestions for Ekos/INDI.") );
     aboutData.addCredit(i18n("Stephane Lucas"), i18n("Extensive testing and suggestions for Ekos Scheduler.") );
+    aboutData.addCredit(i18n("Yuri Fabirovskij"), i18n("Splash screen for both regular KStars and KStars Lite.") );
 
     KAboutData::setApplicationData(aboutData);
 
@@ -131,10 +163,9 @@ int main(int argc, char *argv[])
         if ( !ok ) {
             qWarning() << "Unable to parse arguments: " ;
             qWarning() << "Width: " << parser.value( "width" )
-            << "  Height: " << parser.value( "height" ) << endl;
+                       << "  Height: " << parser.value( "height" ) << endl;
             return 1;
         }
-
         KStarsData *dat = KStarsData::Create();
         QObject::connect( dat, SIGNAL( progressText(QString) ), dat, SLOT( slotConsoleMessage(QString) ) );
         dat->initialize();
@@ -220,9 +251,11 @@ int main(int argc, char *argv[])
         datestring.clear();
     }
 
+#endif
     // Create writable data dir if it does not exist
     QDir writableDir;
     writableDir.mkdir(KSPaths::writableLocation(QStandardPaths::GenericDataLocation));
+#ifndef KSTARS_LITE
 
     KStars::createInstance( true, ! parser.isSet( "paused" ), datestring );
 
@@ -237,8 +270,10 @@ int main(int argc, char *argv[])
             KStars::Instance()->openFITS(u);
         }
     }
-
     QObject::connect(qApp, SIGNAL(lastWindowClosed()), qApp, SLOT(quit()));
+#else
+    KStarsLite::createInstance( true );
+#endif
     return app.exec();
 
 }
