@@ -17,6 +17,8 @@
 
 #include "opscolors.h"
 
+#include <config-kstars.h>
+
 #include <QFile>
 #include <QPixmap>
 #include <QTextStream>
@@ -36,6 +38,12 @@
 #include "kstarsdata.h"
 #include "skymap.h"
 #include "colorscheme.h"
+
+#ifdef HAVE_CFITSIO
+#include "fitsviewer/fitsviewer.h"
+#include "fitsviewer/fitsview.h"
+#endif
+
 #include "skyobjects/starobject.h"
 
 static int ItemColorData = Qt::UserRole + 1;
@@ -86,6 +94,7 @@ OpsColors::OpsColors()
     kcfg_StarColorMode->addItem( i18nc( "show stars as red circles", "Solid Red" ) );
     kcfg_StarColorMode->addItem( i18nc( "show stars as black circles", "Solid Black" ) );
     kcfg_StarColorMode->addItem( i18nc( "show stars as white circles", "Solid White" ) );
+    kcfg_StarColorMode->addItem( i18nc( "show stars as colored circles", "Solid Colors" ) );
     kcfg_StarColorMode->setCurrentIndex( KStarsData::Instance()->colorScheme()->starColorMode() );
 
     if ( KStarsData::Instance()->colorScheme()->starColorMode() != 0 ) //mode is not "Real Colors"
@@ -126,6 +135,13 @@ void OpsColors::newColor( QListWidgetItem *item ) {
     }
 
     KStars::Instance()->map()->forceUpdate();
+
+    #ifdef HAVE_CFITSIO
+    QList<FITSViewer *> viewers = KStars::Instance()->findChildren<FITSViewer *>();
+    foreach(FITSViewer *viewer, viewers){
+        viewer->getCurrentView()->updateFrame();
+    }
+    #endif
 }
 
 void OpsColors::slotPreset( int index ) {
@@ -159,6 +175,10 @@ bool OpsColors::setColors( const QString &filename ) {
     }
 
     KStars::Instance()->map()->forceUpdate();
+    QList<FITSViewer *> viewers = KStars::Instance()->findChildren<FITSViewer *>();
+    foreach(FITSViewer *viewer, viewers){
+        viewer->getCurrentView()->updateFrame();
+    }
     return true;
 }
 
