@@ -33,7 +33,7 @@ class GnomonicProjector : public Projector
 
 public:
     explicit GnomonicProjector(const ViewParams& p);
-    virtual SkyMap::Projection type() const;
+    virtual Projection type() const;
     virtual double radius() const;
     virtual double projectionK(double x) const;
     virtual double projectionL(double x) const;
