@@ -1,6 +1,5 @@
 /*
-    <one line to give the program's name and a brief idea of what it does.>
-    Copyright (C) <year>  <name of author>
+    Copyright (C) 2010 Henry de Valence <hdevalence@gmail.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,13 +22,18 @@
 
 #include "projector.h"
 
-
+/**
+ * @class OrthographicProjector
+ *
+ * Implememntation of <a href="http://en.wikipedia.org/wiki/Orthographic_projection">Orthographic projection</a>
+ *
+ */
 class OrthographicProjector : public Projector
 {
 
 public:
     explicit OrthographicProjector(const ViewParams& p);
-    virtual SkyMap::Projection type() const;
+    virtual Projection type() const;
     virtual double radius() const;
     virtual double projectionK(double x) const;
     virtual double projectionL(double x) const;
