@@ -41,7 +41,9 @@
 #include "Options.h"
 #include "kstarsdata.h"
 #include "skyobjects/skyobject.h"
+#ifndef KSTARS_LITE
 #include "skymap.h"
+#endif
 
 #include "skymesh.h"
 #include "linelist.h"
@@ -182,6 +184,11 @@ void LineListIndex::draw( SkyPainter *skyp )
     preDraw( skyp );
     drawLines( skyp );
 }
+#ifdef KSTARS_LITE
+MeshIterator LineListIndex::visibleTrixels() {
+    return MeshIterator( skyMesh(), drawBuffer() );
+}
+#endif
 
 // This is a callback used int drawLinesInt() and drawLinesFloat()
 SkipList* LineListIndex::skipList( LineList *lineList )
