@@ -20,13 +20,16 @@
 #endif
 #include "starcomponent.h"
 
+#include <QtConcurrent>
 #include <qplatformdefs.h>
 
 #include "Options.h"
 #include "kstarsdata.h"
 #include "skymap.h"
 #include "skyobjects/starobject.h"
+#ifndef KSTARS_LITE
 #include "skyqpainter.h"
+#endif
 #include "skypainter.h"
 
 #include "skymesh.h"
@@ -71,10 +74,18 @@ StarComponent::StarComponent(SkyComposite *parent )
 
     // Actually load data
     emitProgressText( i18n("Loading stars" ) );
+
     loadStaticData();
     // Load any deep star catalogs that are available
     loadDeepStarCatalogs();
+
+    // The following works but can cause crashes sometimes
+    //QtConcurrent::run(this, &StarComponent::loadDeepStarCatalogs);
+
+    //In KStars Lite star images are initialized in SkyMapLite
+#ifndef KSTARS_LITE
     SkyQPainter::initStarImages();
+#endif
 }
 
 StarComponent::~StarComponent() {
@@ -125,20 +136,22 @@ void StarComponent::update( KSNumbers*)
 // We use the update hook to re-index all the stars when the date has changed by
 // more than 150 years.
 
-void StarComponent::reindex( KSNumbers *num )
+bool StarComponent::reindex( KSNumbers *num )
 {
-    if ( ! num ) return;
+    if ( ! num ) return false;
 
     // for large time steps we re-index all points
     if ( fabs( num->julianCenturies() -
                m_reindexNum.julianCenturies() ) > m_reindexInterval ) {
         reindexAll( num );
-        return;
+        return true;
     }
 
+    bool highPM = true;
     // otherwise we just re-index fast movers as needed
     for ( int j = 0; j < m_highPMStars.size(); j++ )
-        m_highPMStars.at( j )->reindex( num, m_starIndex );
+        highPM &= !(m_highPMStars.at( j )->reindex( num, m_starIndex ));
+    return !(highPM);
 }
 
 void StarComponent::reindexAll( KSNumbers *num )
@@ -229,6 +242,7 @@ float StarComponent::zoomMagnitudeLimit() {
 
 void StarComponent::draw( SkyPainter *skyp )
 {
+#ifndef KSTARS_LITE
     if( !selected() )
         return;
 
@@ -325,6 +339,9 @@ void StarComponent::draw( SkyPainter *skyp )
     for( int i =0; i < m_DeepStarComponents.size(); ++i ) {
         m_DeepStarComponents.at( i )->draw( skyp );
     }
+#else
+    Q_UNUSED(skyp)
+#endif
 }
 
 void StarComponent::addLabel( const QPointF& p, StarObject *star )
@@ -468,9 +485,12 @@ bool StarComponent::loadStaticData()
 
             if ( ! name.isEmpty() && name != i18n("star")) {
                 objectNames(SkyObject::STAR).append( name );
+                objectLists(SkyObject::STAR).append(QPair<QString, const SkyObject*>(name,star));
             }
             if ( ! visibleName.isEmpty() && gname != name ) {
-                objectNames(SkyObject::STAR).append( star -> gname(false) );
+                QString gName = star -> gname(false);
+                objectNames(SkyObject::STAR).append( gName );
+                objectLists(SkyObject::STAR).append(QPair<QString, const SkyObject*>(gName,star));
             }
 
             m_ObjectList.append( star );
@@ -583,6 +603,8 @@ StarObject *StarComponent::findByHDIndex( int HDnum ) {
 //
 SkyObject* StarComponent::objectNearest( SkyPoint *p, double &maxrad )
 {
+    m_zoomMagLimit = zoomMagnitudeLimit();
+
     SkyObject *oBest = 0;
 
     MeshIterator region( m_skyMesh, OBJ_NEAREST_BUF );
@@ -606,11 +628,11 @@ SkyObject* StarComponent::objectNearest( SkyPoint *p, double &maxrad )
     // Check up with our Deep Star Components too!
     double rTry, rBest;
     SkyObject *oTry;
-    rBest = maxrad;
+    // JM 2016-03-30: Multiply rBest by a factor of 0.5 so that named stars are preferred to unnamed stars searched below
+    rBest = maxrad * 0.5;
     rTry  = maxrad;
     for( int i = 0; i < m_DeepStarComponents.size(); ++i ) {
         oTry = m_DeepStarComponents.at( i )->objectNearest( p, rTry );
-        // TODO: Should we multiply rBest by a factor < 1, so that we give higher priority to named stars?
         if( rTry < rBest ) {
             rBest = rTry;
             oBest = oTry;
