@@ -17,6 +17,8 @@
 
 #include "kssun.h"
 
+#include <typeinfo>
+
 #include <cmath>
 
 #include "ksnumbers.h"
@@ -29,9 +31,10 @@ KSSun::KSSun( )
     setMag( -26.73 );
 }
 
-KSSun* KSSun::clone() const 
+KSSun* KSSun::clone() const
 {
-    return new KSSun(*this);   
+    Q_ASSERT( typeid( this ) == typeid( static_cast<const KSSun *>( this ) ) ); // Ensure we are not slicing a derived class
+    return new KSSun(*this);
 }
 
 bool KSSun::loadData() {
@@ -88,7 +91,7 @@ bool KSSun::findGeocentricPosition( const KSNumbers *num, const KSPlanetBase *Ea
                 sum[i] += odc.Lon[i][j].A * cos( odc.Lon[i][j].B + odc.Lon[i][j].C*T );
             }
             sum[i] *= Tpow[i];
-            //kDebug() << name() << " : sum[" << i << "] = " << sum[i];
+            //qDebug() << name() << " : sum[" << i << "] = " << sum[i];
         }
 
         EarthLong.setRadians( sum[0] + sum[1] + sum[2] +
