@@ -17,8 +17,8 @@
 
 #include "scriptfunction.h"
 
-#include <qstringlist.h>
-#include <kdebug.h>
+#include <QStringList>
+#include <QDebug>
 
 ScriptFunction::ScriptFunction( const QString &name, const QString &desc,
                                 bool clockfcn, const QString &at1, const QString &an1,
